---
title: <span class="badge builder"></span> QueryEditorArrayExpression
---
# <span class="badge builder"></span> QueryEditorArrayExpression

## Constructor

```python
QueryEditorArrayExpression()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> cloudwatch.QueryEditorArrayExpression
```

### <span class="badge object-method"></span> expressions

```python
def expressions(expressions: list[cogbuilder.Builder[cloudwatch.QueryEditorExpression]]) -> typing.Self
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: typing.Literal["and", "or"]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [QueryEditorArrayExpression](./object-QueryEditorArrayExpression.md)
